/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
import { MessageHeader } from '@aws-crypto/serialize';
import { GetCipher, AwsEsdkJsCipherGCM, NodeAlgorithmSuite } from '@aws-crypto/material-management-node';
interface AccumulatingFrame {
    contentLength: number;
    content: Buffer[];
    sequenceNumber: number;
}
interface EncryptFrame {
    content: Buffer[];
    bodyHeader: Buffer;
    headerSent?: boolean;
    cipher: AwsEsdkJsCipherGCM;
    isFinalFrame: boolean;
}
type ErrBack = (err?: Error) => void;
export declare function getFramedEncryptStream(getCipher: GetCipher, messageHeader: MessageHeader, dispose: () => void, { plaintextLength, suite, }: {
    plaintextLength?: number;
    suite: NodeAlgorithmSuite;
}): {
    _transform(chunk: Buffer, encoding: string, callback: ErrBack): void;
    _flush(callback: ErrBack): void;
    _destroy(): void;
    _read(size: number): void;
    _flushEncryptFrame(encryptingFrame: EncryptFrame): Promise<void>;
    readonly writable: boolean;
    readonly writableEnded: boolean;
    readonly writableFinished: boolean;
    readonly writableHighWaterMark: number;
    readonly writableLength: number;
    readonly writableObjectMode: boolean;
    readonly writableCorked: number;
    allowHalfOpen: boolean;
    _write(chunk: any, encoding: BufferEncoding, callback: (error?: Error | null | undefined) => void): void;
    _writev?(chunks: {
        chunk: any;
        encoding: BufferEncoding;
    }[], callback: (error?: Error | null | undefined) => void): void;
    _final(callback: (error?: Error | null | undefined) => void): void;
    write(chunk: any, encoding?: BufferEncoding | undefined, cb?: ((error: Error | null | undefined) => void) | undefined): boolean;
    write(chunk: any, cb?: ((error: Error | null | undefined) => void) | undefined): boolean;
    setDefaultEncoding(encoding: BufferEncoding): any;
    end(cb?: (() => void) | undefined): any;
    end(chunk: any, cb?: (() => void) | undefined): any;
    end(chunk: any, encoding?: BufferEncoding | undefined, cb?: (() => void) | undefined): any;
    cork(): void;
    uncork(): void;
    addListener(event: "close", listener: () => void): any;
    addListener(event: "data", listener: (chunk: any) => void): any;
    addListener(event: "drain", listener: () => void): any;
    addListener(event: "end", listener: () => void): any;
    addListener(event: "error", listener: (err: Error) => void): any;
    addListener(event: "finish", listener: () => void): any;
    addListener(event: "pause", listener: () => void): any;
    addListener(event: "pipe", listener: (src: import("stream").Readable) => void): any;
    addListener(event: "readable", listener: () => void): any;
    addListener(event: "resume", listener: () => void): any;
    addListener(event: "unpipe", listener: (src: import("stream").Readable) => void): any;
    addListener(event: string | symbol, listener: (...args: any[]) => void): any;
    emit(event: "close"): boolean;
    emit(event: "data", chunk: any): boolean;
    emit(event: "drain"): boolean;
    emit(event: "end"): boolean;
    emit(event: "error", err: Error): boolean;
    emit(event: "finish"): boolean;
    emit(event: "pause"): boolean;
    emit(event: "pipe", src: import("stream").Readable): boolean;
    emit(event: "readable"): boolean;
    emit(event: "resume"): boolean;
    emit(event: "unpipe", src: import("stream").Readable): boolean;
    emit(event: string | symbol, ...args: any[]): boolean;
    on(event: "close", listener: () => void): any;
    on(event: "data", listener: (chunk: any) => void): any;
    on(event: "drain", listener: () => void): any;
    on(event: "end", listener: () => void): any;
    on(event: "error", listener: (err: Error) => void): any;
    on(event: "finish", listener: () => void): any;
    on(event: "pause", listener: () => void): any;
    on(event: "pipe", listener: (src: import("stream").Readable) => void): any;
    on(event: "readable", listener: () => void): any;
    on(event: "resume", listener: () => void): any;
    on(event: "unpipe", listener: (src: import("stream").Readable) => void): any;
    on(event: string | symbol, listener: (...args: any[]) => void): any;
    once(event: "close", listener: () => void): any;
    once(event: "data", listener: (chunk: any) => void): any;
    once(event: "drain", listener: () => void): any;
    once(event: "end", listener: () => void): any;
    once(event: "error", listener: (err: Error) => void): any;
    once(event: "finish", listener: () => void): any;
    once(event: "pause", listener: () => void): any;
    once(event: "pipe", listener: (src: import("stream").Readable) => void): any;
    once(event: "readable", listener: () => void): any;
    once(event: "resume", listener: () => void): any;
    once(event: "unpipe", listener: (src: import("stream").Readable) => void): any;
    once(event: string | symbol, listener: (...args: any[]) => void): any;
    prependListener(event: "close", listener: () => void): any;
    prependListener(event: "data", listener: (chunk: any) => void): any;
    prependListener(event: "drain", listener: () => void): any;
    prependListener(event: "end", listener: () => void): any;
    prependListener(event: "error", listener: (err: Error) => void): any;
    prependListener(event: "finish", listener: () => void): any;
    prependListener(event: "pause", listener: () => void): any;
    prependListener(event: "pipe", listener: (src: import("stream").Readable) => void): any;
    prependListener(event: "readable", listener: () => void): any;
    prependListener(event: "resume", listener: () => void): any;
    prependListener(event: "unpipe", listener: (src: import("stream").Readable) => void): any;
    prependListener(event: string | symbol, listener: (...args: any[]) => void): any;
    prependOnceListener(event: "close", listener: () => void): any;
    prependOnceListener(event: "data", listener: (chunk: any) => void): any;
    prependOnceListener(event: "drain", listener: () => void): any;
    prependOnceListener(event: "end", listener: () => void): any;
    prependOnceListener(event: "error", listener: (err: Error) => void): any;
    prependOnceListener(event: "finish", listener: () => void): any;
    prependOnceListener(event: "pause", listener: () => void): any;
    prependOnceListener(event: "pipe", listener: (src: import("stream").Readable) => void): any;
    prependOnceListener(event: "readable", listener: () => void): any;
    prependOnceListener(event: "resume", listener: () => void): any;
    prependOnceListener(event: "unpipe", listener: (src: import("stream").Readable) => void): any;
    prependOnceListener(event: string | symbol, listener: (...args: any[]) => void): any;
    removeListener(event: "close", listener: () => void): any;
    removeListener(event: "data", listener: (chunk: any) => void): any;
    removeListener(event: "drain", listener: () => void): any;
    removeListener(event: "end", listener: () => void): any;
    removeListener(event: "error", listener: (err: Error) => void): any;
    removeListener(event: "finish", listener: () => void): any;
    removeListener(event: "pause", listener: () => void): any;
    removeListener(event: "pipe", listener: (src: import("stream").Readable) => void): any;
    removeListener(event: "readable", listener: () => void): any;
    removeListener(event: "resume", listener: () => void): any;
    removeListener(event: "unpipe", listener: (src: import("stream").Readable) => void): any;
    removeListener(event: string | symbol, listener: (...args: any[]) => void): any;
    readonly readableAborted: boolean;
    readable: boolean;
    readonly readableDidRead: boolean;
    readonly readableEncoding: BufferEncoding | null;
    readonly readableEnded: boolean;
    readonly readableFlowing: boolean | null;
    readonly readableHighWaterMark: number;
    readonly readableLength: number;
    readonly readableObjectMode: boolean;
    destroyed: boolean;
    _construct?(callback: (error?: Error | null | undefined) => void): void;
    read(size?: number | undefined): any;
    setEncoding(encoding: BufferEncoding): any;
    pause(): any;
    resume(): any;
    isPaused(): boolean;
    unpipe(destination?: NodeJS.WritableStream | undefined): any;
    unshift(chunk: any, encoding?: BufferEncoding | undefined): void;
    wrap(stream: NodeJS.ReadableStream): any;
    push(chunk: any, encoding?: BufferEncoding | undefined): boolean;
    iterator(options?: {
        destroyOnReturn?: boolean | undefined;
    } | undefined): AsyncIterableIterator<any>;
    map(fn: (data: any, options?: Pick<import("stream").ArrayOptions, "signal"> | undefined) => any, options?: import("stream").ArrayOptions | undefined): import("stream").Readable;
    filter(fn: (data: any, options?: Pick<import("stream").ArrayOptions, "signal"> | undefined) => boolean | Promise<boolean>, options?: import("stream").ArrayOptions | undefined): import("stream").Readable;
    destroy(error?: Error | undefined): any;
    [Symbol.asyncIterator](): AsyncIterableIterator<any>;
    pipe<T extends NodeJS.WritableStream>(destination: T, options?: {
        end?: boolean | undefined;
    } | undefined): T;
    [EventEmitter.captureRejectionSymbol]?<K>(error: Error, event: string | symbol, ...args: any[]): void;
    off<K_1>(eventName: string | symbol, listener: (...args: any[]) => void): any;
    removeAllListeners(event?: string | symbol | undefined): any;
    setMaxListeners(n: number): any;
    getMaxListeners(): number;
    listeners<K_2>(eventName: string | symbol): Function[];
    rawListeners<K_3>(eventName: string | symbol): Function[];
    listenerCount<K_4>(eventName: string | symbol, listener?: Function | undefined): number;
    eventNames(): (string | symbol)[];
};
type EncryptFrameInput = {
    pendingFrame: AccumulatingFrame;
    messageHeader: MessageHeader;
    getCipher: GetCipher;
    isFinalFrame: boolean;
    suite: NodeAlgorithmSuite;
};
export declare function getEncryptFrame(input: EncryptFrameInput): EncryptFrame;
export {};
//# sourceMappingURL=framed_encrypt_stream.d.ts.map