/// <reference types="node" />
/// <reference types="node" />
import { NodeEncryptionMaterial, NodeDecryptionMaterial, AwsEsdkKeyObject } from '@aws-crypto/material-management';
import { createCipheriv, createDecipheriv } from 'crypto';
import { AwsESDKSigner, AwsESDKVerify } from './types';
export interface AwsEsdkJsCipherGCM {
    update(data: Buffer): Buffer;
    final(): Buffer;
    getAuthTag(): Buffer;
    setAAD(aad: Buffer): this;
}
export interface AwsEsdkJsDecipherGCM {
    update(data: Buffer): Buffer;
    final(): Buffer;
    setAuthTag(buffer: Buffer): this;
    setAAD(aad: Buffer): this;
}
export interface GetCipher {
    (iv: Uint8Array): AwsEsdkJsCipherGCM;
}
export interface GetCipherInfo {
    (messageId: Uint8Array): {
        getCipher: GetCipher;
        keyCommitment?: Uint8Array;
    };
}
export interface GetSigner {
    (): AwsESDKSigner & {
        awsCryptoSign: () => Buffer;
    };
}
export interface NodeEncryptionMaterialHelper {
    getCipherInfo: GetCipherInfo;
    getSigner?: GetSigner;
    dispose: () => void;
}
export interface GetEncryptHelper {
    (material: NodeEncryptionMaterial): NodeEncryptionMaterialHelper;
}
export declare const getEncryptHelper: GetEncryptHelper;
export interface GetDecipher {
    (iv: Uint8Array): AwsEsdkJsDecipherGCM;
}
export interface GetDecipherInfo {
    (messageId: Uint8Array, commitKey?: Uint8Array): GetDecipher;
}
export interface GetVerify {
    (): AwsESDKVerify & {
        awsCryptoVerify: (signature: Buffer) => boolean;
    };
}
export interface NodeDecryptionMaterialHelper {
    getDecipherInfo: GetDecipherInfo;
    getVerify?: GetVerify;
    dispose: () => void;
}
export interface GetDecryptionHelper {
    (material: NodeDecryptionMaterial): NodeDecryptionMaterialHelper;
}
export declare const getDecryptionHelper: GetDecryptionHelper;
type CreateCryptoIvStream<Material extends NodeEncryptionMaterial | NodeDecryptionMaterial> = Material extends NodeEncryptionMaterial ? typeof createCipheriv : typeof createDecipheriv;
type CryptoStream<Material extends NodeEncryptionMaterial | NodeDecryptionMaterial> = Material extends NodeEncryptionMaterial ? AwsEsdkJsCipherGCM : AwsEsdkJsDecipherGCM;
type CreateCryptoStream<Material extends NodeEncryptionMaterial | NodeDecryptionMaterial> = (iv: Uint8Array) => CryptoStream<Material>;
type CurryHelper<Material extends NodeEncryptionMaterial | NodeDecryptionMaterial> = Material extends NodeEncryptionMaterial ? {
    getCipher: CreateCryptoStream<Material>;
    keyCommitment: Uint8Array;
} : Material extends NodeDecryptionMaterial ? CreateCryptoStream<Material> : never;
export declare function curryCryptoStream<Material extends NodeEncryptionMaterial | NodeDecryptionMaterial>(material: Material, createCryptoIvStream: CreateCryptoIvStream<Material>): (messageId: Uint8Array, commitKey?: Uint8Array) => CurryHelper<Material>;
export declare function nodeKdf(material: NodeEncryptionMaterial | NodeDecryptionMaterial, nonce: Uint8Array, commitKey?: Uint8Array): {
    derivedKey: Uint8Array | AwsEsdkKeyObject;
    keyCommitment?: Uint8Array;
};
export {};
//# sourceMappingURL=material_helpers.d.ts.map