import { WebCryptoAlgorithmSuite } from '@aws-crypto/material-management';
/**
 * WebCrypto subtle.verify expect the signature to be "raw" formated e.g. concat(r,s)
 * where r and s are padded to the key length in bytes.
 *
 * @param derSignature [Uint8Array] The DER formated signature from an Encryption SDK formated blob
 * @param suite [WebCryptoAlgorithmSuite] The Algorithm suite used to create the signature
 * @returns Uint8Array The raw formated signature (r,s) used to verify in WebCrypto
 */
export declare function der2raw(derSignature: Uint8Array, { signatureCurve }: WebCryptoAlgorithmSuite): Uint8Array;
/**
 * WebCrypto subtle.sign returns the signature "raw" formated e.g. concat(r,s)
 * where r and s are padded to the key length in bytes.
 * The Encryption SDK expects the signature to be DER encoded.
 *
 * @param rawSignature [Uint8Array] The "raw" formated signature from WebCrypto subtle.sign
 * @param suite [WebCryptoAlgorithmSuite] The Algorithm suite used to create the signature
 * @returns Uint8Array The DER formated signature
 */
export declare function raw2der(rawSignature: Uint8Array, { signatureCurve }: WebCryptoAlgorithmSuite): Uint8Array;
//# sourceMappingURL=ecdsa_signature.d.ts.map